from setuptools import setup, find_packages
from numpy.distutils.core import setup, Extension

ext1 = Extension(name='gpssnrpy.gpssnr',
        sources=['gpssnrpy/gpssnr.f'], 
        f2py_options=['--verbose'],
        )


with open("README.md", "r") as readme_file:
    readme = readme_file.read()

requirements = ["numpy"]

setup(
    name="gpssnrpy",
    version="0.0.2",
    author="Kristine Larson",
    author_email="kristinem.larson@gmail.com",
    description="A GPS/SNR translation software package1 ",
    long_description=readme,
    long_description_content_type="text/markdown",
    url="https://github.com/kristinemlarson/gpssnrpy/",
    packages=find_packages(),
    include_package_data=True,
    entry_points ={
        'console_scripts': [
            'gpssnr = gpssnrpy.gpssnr_cl:main',
            ],
        },
    install_requires=requirements,
    ext_modules = [ext1],
    classifiers=[
        "Programming Language :: Python :: 3.7",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
    ],
)



# -*- coding: utf-8 -*-
"""
downloads RINEX files
kristine larson
2020sep03 - modified environment variable requirement
need to make this f2py -c -m gpssnr.gpssnr gpssnrpy/gpssnr.f
"""
import argparse
import os
import sys
from numpy import array
import gpssnrpy.gpssnr as gpssnr



def binary(string):
    """
    changes python string to bytes for use in
    fortran code using f2py
    """
    j=bytes(string,'ascii') + b'\0\0'

    return array(j)




def main():
    """
    command line interface for running gpssnr from python
    inputs are the two inputs (obs and nav), output, and snr choice
    """

    parser = argparse.ArgumentParser()
    parser.add_argument("rinex", help="rinexname", type=str)
    parser.add_argument("nav", help="navfile", type=str)
    parser.add_argument("output", help="outputfile", type=str)
    parser.add_argument("filetype",   help="e.g. 50, 66, 88, 99", type=str)

    args = parser.parse_args()


#   assign inputs to normal variable names
    rinexfile = args.rinex 
    snrname = args.output
    orbit = args.nav 
    snrtype = args.filetype

    # these are allowed choices
    if snrtype not in ['99', '66','50','88']:
        print('Illegal snrtype choice',  snrtype)
        sys.exit()

    # check that inputs exist before calling code
    if os.path.isfile(rinexfile) and os.path.isfile(orbit):
        in1 = binary(rinexfile); in2 = binary(snrname);
        in3 = binary(orbit); in4 = binary(snrtype)
        gpssnr.foo(in1,in2,in3,in4)
        if os.path.isfile(snrname):
            print('SUCCESS: SNR file created',snrname)
    else:
        if not os.path.isfile(rinexfile):
            print('RINEX file does not exist', rinexfile)
        if not os.path.isfile(orbit):
            print('Orbit file does not exist', orbit)
        sys.exit()


if __name__ == "__main__":
    main()



# -*- coding: utf-8 -*-
"""
gpssnr_cl.py
command line python code to run gpssnr (fortran) translator 
kristine larson
"""
import argparse
import os
import sys
from numpy import array
# this is the fortran code KL wrote 
import gpssnrpy.gpssnr as gpssnr
import time



def binary(string):
    """
    changes python string to bytes for use in
    fortran code using f2py via numpy
    input is a string, output is bytes with null at the end
    """
    j=bytes(string,'ascii') + b'\0\0'

    return array(j)


def main():
    """
    command line interface for running gpssnr from python
    inputs are the three filenames (input obs, output obs, navigation file), snr choice, and decimation
    if decimation is zero, then no decimation is done
    """

    parser = argparse.ArgumentParser()
    parser.add_argument("rinex", help="rinexname", type=str)
    parser.add_argument("output", help="outputfile", type=str)
    parser.add_argument("nav", help="navfile", type=str)
    parser.add_argument("filetype",   help="e.g. 50, 66, 88, 99", type=str)
    parser.add_argument("-dec", default=None,help="decimation factor in seconds. default is none", type=str)

    args = parser.parse_args()

#   assign inputs to normal variable names
    rinexfile = args.rinex 
    snrname = args.output
    orbit = args.nav 
    snrtype = args.filetype

    if args.dec == None:
        dec = '0'
    else:
        dec = args.dec

    # these are allowed choices
    if snrtype not in ['99', '66','50','88']:
        print('Illegal snrtype choice',  snrtype)
        sys.exit()

    # check that inputs exist before calling code
    if os.path.isfile(rinexfile) and os.path.isfile(orbit):
        in1 = binary(rinexfile); in2 = binary(snrname);
        in3 = binary(orbit); in4 = binary(snrtype)
        in5= binary(dec)
        t1 = time.time()
        gpssnr.foo(in1,in2,in3,in4,in5)
        t2 = time.time()
        if os.path.isfile(snrname):
            print('SUCCESS: SNR file created',snrname, ' Exec time:', '{0:4.2f}'.format(t2-t1))
    else:
        if not os.path.isfile(rinexfile):
            print('RINEX file does not exist', rinexfile)
        if not os.path.isfile(orbit):
            print('Orbit file does not exist', orbit)
        sys.exit()


if __name__ == "__main__":
    main()
